.. _developers-guide-index:

=================
 Developer Guide
=================

:Release: |version|
:Date: |today|

Since nipype is part of the NIPY_ project, we follow the same
conventions documented in the `NIPY Developers Guide
<http://nipy.org/devel>`_. For bleeding-edge version help see `Nightly documentation <http://www.mit.edu/~satra/nipype-nightly/>`_

.. toctree::
   :maxdepth: 2

   writing_custom_interfaces
   gitwash/index
   architecture
   provenance
   software_using_nipype
   testing_nipype


.. include:: ../links_names.txt
